from view.winNuevoModelo import WinNuevoModelo
from view.winConfigModelo import WinConfigModelo
from model.modelo import Modelo
import model.utiles as utiles
import view.errormsg as errormsg
from sqlite3 import IntegrityError
from ctrl.gestorWorkingDir import GestorWorkingDir
from ctrl.gestorExecScript import GestorExecScript
import logging
import bd.comunesBD

class GestorModelo(object):

	__paginaModelo = None
	__winNuevoModelo = None
	__winConfigModelo = None

	def __init__(self, pm):
		self.__paginaModelo = pm
		
	def nuevo(self):
		self.__winNuevoModelo = WinNuevoModelo(self)

	def config(self, OID):
		#Recupera toda la informacion a traves del OID recibido
		#el OID es el nombre del modelo.
		modelo = Modelo.getObject(OID)
				
		self.__winConfigModelo = WinConfigModelo(self, modelo)
		
	def almacenaModelo(self, data):
		modelo = Modelo()

		modelo.nombre = data["nombre"]
		modelo.arquitectura = data["arquitectura"]
		modelo.instalacion = data["fInicial"]
		modelo.entornoGrafico = data["escritorio"]
		modelo.username = data["username"]
		modelo.hostname = data["hostname"]
		modelo.estado = utiles.estado_values[1]
		
		#validacion es una tupla(boolean, mensaje_eror).
		validacion = modelo.checkData()
		if not validacion[0]:
			try:
				modelo.putObject()
				
				self.__paginaModelo.actualiza()
				self.__winNuevoModelo.terminar()
				
				logging.info('Se ha creado un nuevo modelo: %s' % (modelo.nombre))
			except IntegrityError:
				self.__winNuevoModelo.errorValidacion(errormsg.modeloExiste_err)
		else:
			self.__winNuevoModelo.errorValidacion(validacion[1])
			
	def actualizaModelo(self, data):
		modelo = Modelo()

		modelo.nuevoNombre = data["nuevoNombre"]
		modelo.nombre = data["nombre"]
		modelo.arquitectura = data["arquitectura"]
		modelo.instalacion = data["fInicial"]
		modelo.entornoGrafico = data["escritorio"]
		modelo.username = data["username"]
		modelo.hostname = data["hostname"]
		modelo.estado = utiles.estado_values[1]
			
		#validacion es una tupla(boolean, mensaje_eror).
		validacion = modelo.checkData()
		
		if not validacion[0]:
			try:
				modelo.updateObject()
				self.__paginaModelo.actualiza()
				self.__winConfigModelo.terminar()

			except IntegrityError:
				self.__winConfigModelo.errorValidacion(errormsg.modeloExiste_err)
		else:
			self.__winConfigModelo.errorValidacion(validacion[1])


	def desactivar(self, nombre):
		mod = Modelo.getObject(nombre)
		mod.nuevoNombre = mod.nombre
		# comunesBD.desactivarModelo(nombreModelo)
		mod.estado = utiles.estado_values[0]
		mod.updateObject()
		self.__paginaModelo.actualiza()
		
	def generaImagen(self, nombre):
		mod = Modelo.getObject(nombre)
		
		# Lanzar el script de creacion de imagen utilizando el fichero de configuracion
		# generado por el anterior gestor.
		gs = GestorExecScript()
		gs.execBurnImg(mod)
		
		
